@@ -16,6 +16,7 @@
  */
 
 #include "core/Paths.h"
+#include <algorithm>
 #include <core/Database.h>
 #include "gui/EntriesViewHelper.h"
 #include "gui/EntryMenu.h"
@@ -109,7 +110,7 @@ QList<EntryPointer> EntriesViewHelper::selectedEntries() const
 			break;
 		}
 		progressDialog.setValue(i++);
-		EntryPointer entry(qVariantValue<EntryPointer>(index.data(Entry::EntryRole)));
+		EntryPointer entry(index.data(Entry::EntryRole).value<EntryPointer>());
 		if (entry) selectedEntries << entry;
 	}
 	if (!completed) return QList<EntryPointer>();
@@ -249,7 +250,7 @@ void EntriesViewHelper::addNote()
 {
 	QModelIndexList selection = client()->selectionModel()->selectedIndexes();
 	if (selection.size() != 1) return;
-	EntryPointer entry = qVariantValue<EntryPointer >(selection[0].data(Entry::EntryRole));
+	EntryPointer entry(selection[0].data(Entry::EntryRole).value<EntryPointer>());
 	if (!entry) return;
 	EditEntryNotesDialog dialog(*entry, client());
 	if (dialog.exec() != QDialog::Accepted) return;
@@ -304,7 +305,7 @@ QModelIndexList EntriesViewHelper::getAllIndexes(const QModelIndexList& indexes)
 {
 	QSet<QModelIndex> alreadyIn;
 	QModelIndexList ret(getAllIndexes(indexes, alreadyIn));
-	qStableSort(ret.begin(), ret.end(), modelIndexLessThan);
+	std::stable_sort(ret.begin(), ret.end(), modelIndexLessThan);
 	return ret;
 }
 
@@ -319,12 +320,12 @@ QModelIndexList EntriesViewHelper::getAllIndexes(const QModelIndexList& indexes,
 		ret << idx;
 		alreadyIn << idx;
 		// Entries can be put directly into the return list
-		ConstEntryPointer entry(qVariantValue<EntryPointer>(idx.data(Entry::EntryRole)));
+		ConstEntryPointer entry(idx.data(Entry::EntryRole).value<EntryPointer>());
 		if (!entry) {
 			// Non entries indexes must be list - see if they have children
 			QModelIndexList childs;
 			int childsCount = idx.model()->rowCount(idx);
-			for (int i = 0; i < childsCount; i++) childs << idx.child(i, 0);
+			for (int i = 0; i < childsCount; i++) childs << idx.model()->index(i, 0);
 			ret += getAllIndexes(childs, alreadyIn);
 		}
 	}
@@ -389,7 +390,7 @@ void EntriesViewHelper::tabExport()
 	// Dummy entry to notify Anki that tab is our delimiter
 	//outFile.write("\t\t\n");
 	foreach (const QModelIndex &idx, entries) {
-		ConstEntryPointer entry = qVariantValue<EntryPointer>(idx.data(Entry::EntryRole));
+		ConstEntryPointer entry(idx.data(Entry::EntryRole).value<EntryPointer>());
 		// We cannot "export" lists due to the file purpose
 		if (!entry) continue;
 		QStringList writings = entry->writings();
@@ -435,7 +436,7 @@ void EntriesViewHelper::jsExport()
 	QList<ConstEntryPointer> realEntries;
 
 	foreach (const QModelIndex &idx, entries) {
-		ConstEntryPointer entry = qVariantValue<EntryPointer>(idx.data(Entry::EntryRole));
+		ConstEntryPointer entry(idx.data(Entry::EntryRole).value<EntryPointer>());
 		// We cannot "export" lists due to the file purpose
 		if (!entry) continue;
 		realEntries << entry;
