@@ -18,13 +18,14 @@
 #include <QtDebug>
 
 #include "core/Database.h"
-#include "core/EntryListModel.h"
 #include "core/EntryListCache.h"
+#include "gui/EntryListModel.h"
 #include "gui/EntryListView.h"
 
 #include <QInputDialog>
 #include <QMessageBox>
 #include <QToolBar>
+#include <QDrag>
 
 PreferenceItem<bool> EntryListView::smoothScrollingSetting("mainWindow/lists", "smoothScrolling", true);
 PreferenceItem<QString> EntryListView::textFontSetting("mainWindow/lists", "textFont", "");
@@ -150,7 +151,7 @@ bool EntryListView::deleteEntries(const QModelIndex &index)
 	int nRows = m->rowCount(index);
 	// Delete all children
 	while (nRows--)
-		if (!deleteEntries(index.child(0, 0))) return false;
+		if (!deleteEntries(index.model()->index(0, 0))) return false;
 
 	// Remove ourselves from the model
 	EntryRef ref(index.data(Entry::EntryRefRole).value<EntryRef>());
