@@ -106,12 +106,14 @@ static const QMap<QString, QString> _langMapping()
 	ret.insert("nb", QT_TRANSLATE_NOOP("GeneralPreferences", "Norvegian Bokmal"));
 	ret.insert("nl", QT_TRANSLATE_NOOP("GeneralPreferences", "Dutch"));
 	ret.insert("pl", QT_TRANSLATE_NOOP("GeneralPreferences", "Polish"));
-	ret.insert("pt", QT_TRANSLATE_NOOP("GeneralPreferences", "Portuguese"));
+	ret.insert("pt_BR", QT_TRANSLATE_NOOP("GeneralPreferences", "Portuguese (Brazil)"));
 	ret.insert("ru", QT_TRANSLATE_NOOP("GeneralPreferences", "Russian"));
 	ret.insert("sv", QT_TRANSLATE_NOOP("GeneralPreferences", "Swedish"));
 	ret.insert("th", QT_TRANSLATE_NOOP("GeneralPreferences", "Thai"));
 	ret.insert("tr", QT_TRANSLATE_NOOP("GeneralPreferences", "Turkish"));
+	ret.insert("uk", QT_TRANSLATE_NOOP("GeneralPreferences", "Ukrainian"));
 	ret.insert("vi", QT_TRANSLATE_NOOP("GeneralPreferences", "Vietnamese"));
+	ret.insert("zh", QT_TRANSLATE_NOOP("GeneralPreferences", "Chinese"));
 	return ret;
 }
 
@@ -163,8 +165,6 @@ GeneralPreferences::GeneralPreferences(QWidget *parent) : PreferencesWindowCateg
 
 	connect(checkForUpdates, SIGNAL(stateChanged(int)), this, SLOT(onCheckUpdatesChecked(int)));
 	connect(checkInterval, SIGNAL(valueChanged(int)), this, SLOT(updateNextCheckLabel()));
-
-	connect(cacheSizeDefault, SIGNAL(toggled(bool)), this, SLOT(onCacheSizeDefaultChecked(bool)));
 }
 
 void GeneralPreferences::refresh()
@@ -190,9 +190,6 @@ void GeneralPreferences::refresh()
 	checkForUpdates->setChecked(MainWindow::autoCheckUpdates.value());
 	checkForBetaUpdates->setChecked(MainWindow::autoCheckBetaUpdates.value());
 	checkInterval->setValue(MainWindow::updateCheckInterval.value());
-
-	cacheSize->setValue(EntriesCache::cacheSize.value());
-	cacheSizeDefault->setChecked(EntriesCache::cacheSize.isDefault());
 }
 
 void GeneralPreferences::onCheckUpdatesChecked(int checked)
@@ -218,17 +215,6 @@ void GeneralPreferences::updateNextCheckLabel()
 	}
 }
 
-void GeneralPreferences::onCacheSizeDefaultChecked(bool checked)
-{
-	if (checked) {
-		cacheSize->setValue(EntriesCache::cacheSize.defaultValue());
-		cacheSize->setEnabled(false);
-	}
-	else {
-		cacheSize->setEnabled(true);
-	}
-}
-
 void GeneralPreferences::applySettings()
 {
 	// Default font
@@ -252,10 +238,6 @@ void GeneralPreferences::applySettings()
 	MainWindow::autoCheckUpdates.set(checkForUpdates->isChecked());
 	MainWindow::autoCheckBetaUpdates.set(checkForBetaUpdates->isChecked());
 	MainWindow::updateCheckInterval.set(checkInterval->value());
-
-	// Cache size
-	if (cacheSizeDefault->isChecked()) EntriesCache::cacheSize.reset();
-	else EntriesCache::cacheSize.set(cacheSize->value());
 }
 
 EntryDelegatePreferences::EntryDelegatePreferences(QWidget *parent) : QWidget(parent)
